use uuid::Uuid;

use crate::db::schema::User;

use super::schema::DollTagsDb;

pub async fn get(mut db: DollTagsDb, username: &str) -> sqlx::Result<Option<User>> {
	sqlx::query_as!(User, "select * from users where username = $1", username)
		.fetch_optional(&mut **db)
		.await
}

pub async fn get_by_id(mut db: DollTagsDb, id: &Uuid) -> sqlx::Result<Option<User>> {
	sqlx::query_as!(User, "select * from users where id = $1", id)
		.fetch_optional(&mut **db)
		.await
}

pub async fn create(
	mut db: DollTagsDb,
	username: &str,
	hashed_password: &str,
	email: Option<&str>,
) -> sqlx::Result<Uuid> {
	sqlx::query_scalar!(
		"insert into users (username, password, email) values ($1, $2, $3) returning id",
		username,
		hashed_password,
		email,
	)
	.fetch_one(&mut **db)
	.await
}
