use rocket::response::Redirect;
use rocket_dyn_templates::{context, Template};

use crate::{
	db::{
		doll,
		schema::{DollTagsDb, User},
	},
	pages::CommonTemplateState,
};

use super::error_handlers::PageResult;

#[get("/")]
pub async fn index(mut db: DollTagsDb, user: User, meta: CommonTemplateState) -> PageResult {
	let tags = doll::list(&mut *db, &user.id).await?;
	let archived_tags = doll::list_archived(&mut *db, &user.id).await?;

	Ok(Template::render(
		"account/index",
		context! {
			meta,
			user,
			tags,
			archived_tags,
		},
	)
	.into())
}

#[get("/settings")]
pub fn show_settings(user: User, meta: CommonTemplateState) -> Template {
	todo!("woof");
}

#[get("/delete/<id>")]
pub async fn ask_delete(
	mut db: DollTagsDb,
	id: i32,
	_user: User,
	meta: CommonTemplateState,
) -> PageResult {
	let db_tag = doll::get(&mut *db, id, "").await?;

	if let Some(tag) = db_tag {
		Ok(Template::render(
			"tag/delete",
			context! {
				meta,
				tag,
			},
		)
		.into())
	} else {
		Ok(Redirect::to(uri!("/account", index)).into())
	}
}

#[get("/yes_delete_this/<id>")]
pub async fn confirm_delete(mut db: DollTagsDb, id: i32, _user: User) -> PageResult {
	doll::delete(&mut *db, id).await?;
	Ok(Redirect::to(uri!("/account", index)).into())
}
